# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nautobot_golden_config',
 'nautobot_golden_config.api',
 'nautobot_golden_config.graphql',
 'nautobot_golden_config.migrations',
 'nautobot_golden_config.nornir_plays',
 'nautobot_golden_config.tests',
 'nautobot_golden_config.tests.test_nornir_plays',
 'nautobot_golden_config.tests.test_utilities',
 'nautobot_golden_config.utilities']

package_data = \
{'': ['*'], 'nautobot_golden_config': ['templates/nautobot_golden_config/*']}

install_requires = \
['astroid>=2.5.5,<3.0.0',
 'django-debug-toolbar>=3.2.1,<4.0.0',
 'django-pivot>=1.8.1,<2.0.0',
 'matplotlib>=3.3.2,<4.0.0',
 'nautobot-plugin-nornir>=0.9.3']

setup_kwargs = {
    'name': 'nautobot-golden-config',
    'version': '0.9.5',
    'description': 'A plugin for configuration on nautobot',
    'long_description': '# nautobot-golden-config\n\nA plugin for [Nautobot](https://github.com/nautobot/nautobot) that intends to provide context around golden configuration.\n\n**This version is currently in Beta and will require a rebuild of the database for a 1.0 release.**\n\n# Overview\n\nYou may see the [Navigating Overview](./docs/navigating-golden.md) documentation for an overview of navigating through the different areas of this plugin. You may also see the [FAQ](./docs/FAQ.md) for commonly asked questions.\n\nThe golden configuration plugin performs four primary actions, each of which can be toggled on with a respective `enable_*` setting, covered in detail \nlater in the readme. \n\n* Configuration Backup - Is a Nornir process to connect to devices, optionally parse out lines/secrets, backup the configuration, and save to a Git repository.\n    * see [Navigating Backup](./docs/navigating-backup.md) for more information\n* Configuration Intended - Is a Nornir process to generate configuration based on a Git repo of Jinja files and a Git repo to store the intended configuration.\n    * see [Navigating Intended](./docs/navigating-intended.md) for more information\n* Source of Truth Aggregation - Is a GraphQL query per device with that creates a data structure used in the generation of configuration.\n    * see [Navigating SoTAgg](./docs/navigating-sot-agg.md) for more information\n* Configuration Compliance - Is a Nornir process to run comparison of the actual (via backups) and intended (via Jinja file creation) CLI configurations.\n    * see [Navigating Compliance](./docs/navigating-compliance.md) for more information\n\nThe operator\'s of their own Nautobot instance are welcome to use any combination of these features. Though the appearance may seem like they are tightly \ncoupled, this isn\'t actually the case. For example, one can obtain backup configurations from their current RANCID/Oxidized process and simply provide a Git Repo\nof the location of the backup configurations, and the compliance process would work the same way. Also, another user may only want to generate configurations,\nbut not want to use other features, which is perfectly fine to do so.\n\n## Screenshots\n\nThere are many features and capabilities the plugin provides into the Nautobot ecosystem. The following screenshots are intended to provide a quick visual overview of some of these features.\n\nThe golden configuration is driven by jobs that run a series of tasks and the result is captured in this overview.\n\n![Overview](./docs/img/golden-overview.png)\n\nThe compliance report provides a high-level overview on the compliance of your network.\n![Compliance Report](./docs/img/compliance-report.png)\n\nThe compliance overview will provide a per device and feature overview on the compliance of your network devices.\n![Compliance Overview](./docs/img/compliance-overview.png)\n\nDrilling into a specific device and feature, you can get an immediate detailed understanding of your device.\n![Compliance Device](./docs/img/compliance-device.png)\n\n![Compliance Rule](./docs/img/compliance-rule.png)\n\n## Plugin Settings\n\nThere is a setting to determine the inclusion of any of the four given components.\n\n* The `enable_backup`, `enable_compliance`, `enable_intended`, and `enable_sotagg` will toggle inclusion of the entire component.\n\n# Installation\n\nPlugins can be installed manually or use Python\'s `pip`. See the [nautobot documentation](https://nautobot.readthedocs.io/en/latest/plugins/#install-the-package) for more details. The pip package name for this plugin is [`nautobot-golden-config`](https://pypi.org/project/nautobot-golden-config/)\n\n> The plugin is compatible with Nautobot 1.0.0 and higher\n\n**Prerequisite:** The plugin relies on [`nautobot_plugin_nornir`](https://pypi.org/project/nautobot-plugin-nornir/) to be installed and both plugins to be enabled in your configuration settings.\n\n**Required:** The following block of code below shows the additional configuration required to be added to your `nautobot_config.py` file:\n- append `"nautobot_golden_config"` to the `PLUGINS` list\n- append the `"nautobot_golden_config"` dictionary to the `PLUGINS_CONFIG` dictionary\n\n```python\nPLUGINS = ["nautobot_plugin_nornir", "nautobot_golden_config"]\n\nPLUGINS_CONFIG = {\n    "nautobot_plugin_nornir": {\n        "nornir_settings": {\n            "credentials": "nautobot_plugin_nornir.plugins.credentials.env_vars.CredentialsEnvVars",\n            "runner": {\n                "plugin": "threaded",\n                "options": {\n                    "num_workers": 20,\n                },\n            },\n        },\n    },\n    "nautobot_golden_config": {\n        "per_feature_bar_width": 0.15,\n        "per_feature_width": 13,\n        "per_feature_height": 4,\n        "enable_backup": True,\n        "enable_compliance": True,\n        "enable_intended": True,\n        "enable_sotagg": True,\n        "sot_agg_transposer": None,\n        "platform_slug_map": None,\n    },\n}\n\n```\n\nThe plugin behavior can be controlled with the following list of settings. \n\n| Key     | Example | Default | Description                          |\n| ------- | ------ | -------- | ------------------------------------- |\n| enable_backup | True | True | A boolean to represent whether or not to run backup configurations within the plugin. |\n| enable_compliance | True | True | A boolean to represent whether or not to run the compliance process within the plugin. |\n| enable_intended | True | True | A boolean to represent whether or not to generate intended configurations within the plugin. |\n| enable_sotagg | True | True | A boolean to represent whether or not to provide a GraphQL query per device to allow the intended configuration to provide data variables to the plugin. |\n| platform_slug_map | {"cisco_wlc": "cisco_aireos"} | None | A dictionary in which the key is the platform slug and the value is what netutils uses in any "network_os" parameter. |\n| sot_agg_transposer | mypkg.transposer | - | A string representation of a function that can post-process the graphQL data. |\n| per_feature_bar_width | 0.15 | 0.15 | The width of the table bar within the overview report | \n| per_feature_width | 13 | 13 | The width in inches that the overview table can be. | \n| per_feature_height | 4 | 4 | The height in inches that the overview table can be. | \n\n> Note: Over time the intention is to make the compliance report more dynamic, but for now allow users to configure the `per_*` configs in a way that fits best for them.\n\n> Note: Review [`nautobot_plugin_nornir`](https://pypi.org/project/nautobot-plugin-nornir/) for Nornir and dispatcher configuration options. \n\n# Contributing\n\nPull requests are welcomed and automatically built and tested against multiple versions of Python and Nautobot through TravisCI.\n\nThe project is packaged with a light development environment based on `docker-compose` to help with the local development of the project and to run tests within TravisCI.\n\nThe project is following Network to Code software development guidelines and are leveraging the following:\n- Black, Pylint, Bandit, flake8, and pydocstyle for Python linting and formatting.\n- Django unit test to ensure the plugin is working properly.\n\n## CLI Helper Commands\n\nThe project features a CLI helper based on [invoke](http://www.pyinvoke.org/) to help setup the development environment. The commands are listed below in 3 categories:\n- `dev environment`\n- `utility`\n- `testing`. \n\nEach command can be executed with `invoke <command>`. All commands support the arguments `--nautobot-ver` and `--python-ver` if you want to manually define the version of Python and Nautobot to use. Each command also has its own help `invoke <command> --help`\n\n### Local dev environment\n\n```\n  build            Build all docker images.\n  debug            Start Nautobot and its dependencies in debug mode.\n  destroy          Destroy all containers and volumes.\n  restart          Restart Nautobot and its dependencies in detached mode.\n  start            Start Nautobot and its dependencies in detached mode.\n  stop             Stop Nautobot and its dependencies.\n```\n\n### Utility \n\n```\n  cli              Launch a bash shell inside the running Nautobot container.\n  create-user      Create a new user in django (default: admin), will prompt for password.\n  makemigrations   Run Make Migration in Django.\n  nbshell          Launch a nbshell session.\n```\n\n### Testing \n\n```\n  bandit           Run bandit to validate basic static code security analysis.\n  black            Run black to check that Python files adhere to its style standards.\n  flake8           Run flake8 to check that Python files adhere to its style standards.\n  pydocstyle       Run pydocstyle to validate docstring formatting adheres to NTC defined standards.\n  pylint           Run pylint code analysis.\n  tests            Run all tests for this plugin.\n  unittest         Run Django unit tests for the plugin.\n```\n',
    'author': 'Network to Code, LLC',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nautobot/nautobot-golden-config',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
